# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['UserArgs', 'User']

@pulumi.input_type
class UserArgs:
    def __init__(__self__, *,
                 email: pulumi.Input[_builtins.str],
                 group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a User resource.
        :param pulumi.Input[_builtins.str] email: The email of the user.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_ids: The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        :param pulumi.Input[_builtins.str] name: The name of the user.
        """
        pulumi.set(__self__, "email", email)
        if group_ids is not None:
            pulumi.set(__self__, "group_ids", group_ids)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Input[_builtins.str]:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="groupIds")
    def group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        """
        return pulumi.get(self, "group_ids")

    @group_ids.setter
    def group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "group_ids", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _UserState:
    def __init__(__self__, *,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 is_email_verified: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_imported_from_identity_provider: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_password_expired: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_two_factor_auth_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_user_locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering User resources.
        :param pulumi.Input[_builtins.str] email: The email of the user.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_ids: The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        :param pulumi.Input[_builtins.bool] is_email_verified: Flag indicating whether or not the users email has been verified.
        :param pulumi.Input[_builtins.bool] is_imported_from_identity_provider: Flag indicating whether or not the user was imported from an identity provider.
        :param pulumi.Input[_builtins.bool] is_password_expired: Flag indicating whether or not the users password has expired.
        :param pulumi.Input[_builtins.bool] is_two_factor_auth_enabled: Flag indicating whether or not two-factor authentication is enabled for the user.
        :param pulumi.Input[_builtins.bool] is_user_locked: Flag indicating whether or not the user is locked out.
        :param pulumi.Input[_builtins.str] name: The name of the user.
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if group_ids is not None:
            pulumi.set(__self__, "group_ids", group_ids)
        if is_email_verified is not None:
            pulumi.set(__self__, "is_email_verified", is_email_verified)
        if is_imported_from_identity_provider is not None:
            pulumi.set(__self__, "is_imported_from_identity_provider", is_imported_from_identity_provider)
        if is_password_expired is not None:
            pulumi.set(__self__, "is_password_expired", is_password_expired)
        if is_two_factor_auth_enabled is not None:
            pulumi.set(__self__, "is_two_factor_auth_enabled", is_two_factor_auth_enabled)
        if is_user_locked is not None:
            pulumi.set(__self__, "is_user_locked", is_user_locked)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def email(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @email.setter
    def email(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "email", value)

    @_builtins.property
    @pulumi.getter(name="groupIds")
    def group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        """
        return pulumi.get(self, "group_ids")

    @group_ids.setter
    def group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "group_ids", value)

    @_builtins.property
    @pulumi.getter(name="isEmailVerified")
    def is_email_verified(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag indicating whether or not the users email has been verified.
        """
        return pulumi.get(self, "is_email_verified")

    @is_email_verified.setter
    def is_email_verified(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_email_verified", value)

    @_builtins.property
    @pulumi.getter(name="isImportedFromIdentityProvider")
    def is_imported_from_identity_provider(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag indicating whether or not the user was imported from an identity provider.
        """
        return pulumi.get(self, "is_imported_from_identity_provider")

    @is_imported_from_identity_provider.setter
    def is_imported_from_identity_provider(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_imported_from_identity_provider", value)

    @_builtins.property
    @pulumi.getter(name="isPasswordExpired")
    def is_password_expired(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag indicating whether or not the users password has expired.
        """
        return pulumi.get(self, "is_password_expired")

    @is_password_expired.setter
    def is_password_expired(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_password_expired", value)

    @_builtins.property
    @pulumi.getter(name="isTwoFactorAuthEnabled")
    def is_two_factor_auth_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag indicating whether or not two-factor authentication is enabled for the user.
        """
        return pulumi.get(self, "is_two_factor_auth_enabled")

    @is_two_factor_auth_enabled.setter
    def is_two_factor_auth_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_two_factor_auth_enabled", value)

    @_builtins.property
    @pulumi.getter(name="isUserLocked")
    def is_user_locked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag indicating whether or not the user is locked out.
        """
        return pulumi.get(self, "is_user_locked")

    @is_user_locked.setter
    def is_user_locked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_user_locked", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("harness:index/user:User")
class User(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness user

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        john_doe = harness.User("john_doe",
            name="John Doe",
            email="john.doe@example.com")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the email address of the user

        ```sh
        $ pulumi import harness:index/user:User john_doe john.doe@example.com
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] email: The email of the user.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_ids: The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        :param pulumi.Input[_builtins.str] name: The name of the user.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness user

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        john_doe = harness.User("john_doe",
            name="John Doe",
            email="john.doe@example.com")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the email address of the user

        ```sh
        $ pulumi import harness:index/user:User john_doe john.doe@example.com
        ```

        :param str resource_name: The name of the resource.
        :param UserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 email: Optional[pulumi.Input[_builtins.str]] = None,
                 group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserArgs.__new__(UserArgs)

            if email is None and not opts.urn:
                raise TypeError("Missing required property 'email'")
            __props__.__dict__["email"] = email
            __props__.__dict__["group_ids"] = group_ids
            __props__.__dict__["name"] = name
            __props__.__dict__["is_email_verified"] = None
            __props__.__dict__["is_imported_from_identity_provider"] = None
            __props__.__dict__["is_password_expired"] = None
            __props__.__dict__["is_two_factor_auth_enabled"] = None
            __props__.__dict__["is_user_locked"] = None
        super(User, __self__).__init__(
            'harness:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            email: Optional[pulumi.Input[_builtins.str]] = None,
            group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            is_email_verified: Optional[pulumi.Input[_builtins.bool]] = None,
            is_imported_from_identity_provider: Optional[pulumi.Input[_builtins.bool]] = None,
            is_password_expired: Optional[pulumi.Input[_builtins.bool]] = None,
            is_two_factor_auth_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            is_user_locked: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'User':
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] email: The email of the user.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] group_ids: The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        :param pulumi.Input[_builtins.bool] is_email_verified: Flag indicating whether or not the users email has been verified.
        :param pulumi.Input[_builtins.bool] is_imported_from_identity_provider: Flag indicating whether or not the user was imported from an identity provider.
        :param pulumi.Input[_builtins.bool] is_password_expired: Flag indicating whether or not the users password has expired.
        :param pulumi.Input[_builtins.bool] is_two_factor_auth_enabled: Flag indicating whether or not two-factor authentication is enabled for the user.
        :param pulumi.Input[_builtins.bool] is_user_locked: Flag indicating whether or not the user is locked out.
        :param pulumi.Input[_builtins.str] name: The name of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserState.__new__(_UserState)

        __props__.__dict__["email"] = email
        __props__.__dict__["group_ids"] = group_ids
        __props__.__dict__["is_email_verified"] = is_email_verified
        __props__.__dict__["is_imported_from_identity_provider"] = is_imported_from_identity_provider
        __props__.__dict__["is_password_expired"] = is_password_expired
        __props__.__dict__["is_two_factor_auth_enabled"] = is_two_factor_auth_enabled
        __props__.__dict__["is_user_locked"] = is_user_locked
        __props__.__dict__["name"] = name
        return User(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def email(self) -> pulumi.Output[_builtins.str]:
        """
        The email of the user.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter(name="groupIds")
    def group_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The groups the user belongs to. This is only used during the creation of the user. The groups are not updated after the user is created. When using this option you should also set `lifecycle = { ignore_changes = ["group_ids"] }`.
        """
        return pulumi.get(self, "group_ids")

    @_builtins.property
    @pulumi.getter(name="isEmailVerified")
    def is_email_verified(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag indicating whether or not the users email has been verified.
        """
        return pulumi.get(self, "is_email_verified")

    @_builtins.property
    @pulumi.getter(name="isImportedFromIdentityProvider")
    def is_imported_from_identity_provider(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag indicating whether or not the user was imported from an identity provider.
        """
        return pulumi.get(self, "is_imported_from_identity_provider")

    @_builtins.property
    @pulumi.getter(name="isPasswordExpired")
    def is_password_expired(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag indicating whether or not the users password has expired.
        """
        return pulumi.get(self, "is_password_expired")

    @_builtins.property
    @pulumi.getter(name="isTwoFactorAuthEnabled")
    def is_two_factor_auth_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag indicating whether or not two-factor authentication is enabled for the user.
        """
        return pulumi.get(self, "is_two_factor_auth_enabled")

    @_builtins.property
    @pulumi.getter(name="isUserLocked")
    def is_user_locked(self) -> pulumi.Output[_builtins.bool]:
        """
        Flag indicating whether or not the user is locked out.
        """
        return pulumi.get(self, "is_user_locked")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the user.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDiscoverySettingResult',
    'AwaitableGetDiscoverySettingResult',
    'get_discovery_setting',
    'get_discovery_setting_output',
]

@pulumi.output_type
class GetDiscoverySettingResult:
    """
    A collection of values returned by getDiscoverySetting.
    """
    def __init__(__self__, correlation_id=None, created_at=None, id=None, image_registries=None, org_identifier=None, project_identifier=None, updated_at=None):
        if correlation_id and not isinstance(correlation_id, str):
            raise TypeError("Expected argument 'correlation_id' to be a str")
        pulumi.set(__self__, "correlation_id", correlation_id)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_registries and not isinstance(image_registries, list):
            raise TypeError("Expected argument 'image_registries' to be a list")
        pulumi.set(__self__, "image_registries", image_registries)
        if org_identifier and not isinstance(org_identifier, str):
            raise TypeError("Expected argument 'org_identifier' to be a str")
        pulumi.set(__self__, "org_identifier", org_identifier)
        if project_identifier and not isinstance(project_identifier, str):
            raise TypeError("Expected argument 'project_identifier' to be a str")
        pulumi.set(__self__, "project_identifier", project_identifier)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="correlationId")
    def correlation_id(self) -> Optional[_builtins.str]:
        """
        Correlation ID for the request.
        """
        return pulumi.get(self, "correlation_id")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Timestamp when the setting was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="imageRegistries")
    def image_registries(self) -> Sequence['outputs.GetDiscoverySettingImageRegistryResult']:
        """
        Image registry configuration.
        """
        return pulumi.get(self, "image_registries")

    @_builtins.property
    @pulumi.getter(name="orgIdentifier")
    def org_identifier(self) -> Optional[_builtins.str]:
        """
        The organization identifier.
        """
        return pulumi.get(self, "org_identifier")

    @_builtins.property
    @pulumi.getter(name="projectIdentifier")
    def project_identifier(self) -> Optional[_builtins.str]:
        """
        The project identifier.
        """
        return pulumi.get(self, "project_identifier")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Timestamp when the setting was last updated.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetDiscoverySettingResult(GetDiscoverySettingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDiscoverySettingResult(
            correlation_id=self.correlation_id,
            created_at=self.created_at,
            id=self.id,
            image_registries=self.image_registries,
            org_identifier=self.org_identifier,
            project_identifier=self.project_identifier,
            updated_at=self.updated_at)


def get_discovery_setting(correlation_id: Optional[_builtins.str] = None,
                          org_identifier: Optional[_builtins.str] = None,
                          project_identifier: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDiscoverySettingResult:
    """
    Data source for retrieving service discovery settings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch service discovery setting by name
    example = harness.service.get_discovery_setting(org_identifier="<org_identifier>",
        project_identifier="<project_identifier>")
    ```


    :param _builtins.str correlation_id: Correlation ID for the request.
    :param _builtins.str org_identifier: The organization identifier.
    :param _builtins.str project_identifier: The project identifier.
    """
    __args__ = dict()
    __args__['correlationId'] = correlation_id
    __args__['orgIdentifier'] = org_identifier
    __args__['projectIdentifier'] = project_identifier
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:service/getDiscoverySetting:getDiscoverySetting', __args__, opts=opts, typ=GetDiscoverySettingResult).value

    return AwaitableGetDiscoverySettingResult(
        correlation_id=pulumi.get(__ret__, 'correlation_id'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        image_registries=pulumi.get(__ret__, 'image_registries'),
        org_identifier=pulumi.get(__ret__, 'org_identifier'),
        project_identifier=pulumi.get(__ret__, 'project_identifier'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_discovery_setting_output(correlation_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 org_identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 project_identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDiscoverySettingResult]:
    """
    Data source for retrieving service discovery settings.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    # Data source to fetch service discovery setting by name
    example = harness.service.get_discovery_setting(org_identifier="<org_identifier>",
        project_identifier="<project_identifier>")
    ```


    :param _builtins.str correlation_id: Correlation ID for the request.
    :param _builtins.str org_identifier: The organization identifier.
    :param _builtins.str project_identifier: The project identifier.
    """
    __args__ = dict()
    __args__['correlationId'] = correlation_id
    __args__['orgIdentifier'] = org_identifier
    __args__['projectIdentifier'] = project_identifier
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:service/getDiscoverySetting:getDiscoverySetting', __args__, opts=opts, typ=GetDiscoverySettingResult)
    return __ret__.apply(lambda __response__: GetDiscoverySettingResult(
        correlation_id=pulumi.get(__response__, 'correlation_id'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        image_registries=pulumi.get(__response__, 'image_registries'),
        org_identifier=pulumi.get(__response__, 'org_identifier'),
        project_identifier=pulumi.get(__response__, 'project_identifier'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PlatformApiKeyArgs', 'PlatformApiKey']

@pulumi.input_type
class PlatformApiKeyArgs:
    def __init__(__self__, *,
                 account_id: pulumi.Input[_builtins.str],
                 apikey_type: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 parent_id: pulumi.Input[_builtins.str],
                 default_time_to_expire_token: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a PlatformApiKey resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.int] default_time_to_expire_token: Default expiration time of the Token within API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "account_id", account_id)
        pulumi.set(__self__, "apikey_type", apikey_type)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "parent_id", parent_id)
        if default_time_to_expire_token is not None:
            pulumi.set(__self__, "default_time_to_expire_token", default_time_to_expire_token)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Input[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @apikey_type.setter
    def apikey_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "apikey_type", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Input[_builtins.str]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter(name="defaultTimeToExpireToken")
    def default_time_to_expire_token(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default expiration time of the Token within API Key
        """
        return pulumi.get(self, "default_time_to_expire_token")

    @default_time_to_expire_token.setter
    def default_time_to_expire_token(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_time_to_expire_token", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PlatformApiKeyState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default_time_to_expire_token: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering PlatformApiKey resources.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.int] default_time_to_expire_token: Default expiration time of the Token within API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if apikey_type is not None:
            pulumi.set(__self__, "apikey_type", apikey_type)
        if default_time_to_expire_token is not None:
            pulumi.set(__self__, "default_time_to_expire_token", default_time_to_expire_token)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if parent_id is not None:
            pulumi.set(__self__, "parent_id", parent_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @apikey_type.setter
    def apikey_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "apikey_type", value)

    @_builtins.property
    @pulumi.getter(name="defaultTimeToExpireToken")
    def default_time_to_expire_token(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Default expiration time of the Token within API Key
        """
        return pulumi.get(self, "default_time_to_expire_token")

    @default_time_to_expire_token.setter
    def default_time_to_expire_token(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "default_time_to_expire_token", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @parent_id.setter
    def parent_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:index/platformApiKey:PlatformApiKey")
class PlatformApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default_time_to_expire_token: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating ApiKeys.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <parent_id>/<apikey_id>/<apikey_type>
        ```

        Import org level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <org_id>/<parent_id>/<apikey_id>/<apikey_type>
        ```

        Import project level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <org_id>/<project_id>/<parent_id>/<apikey_id>/<apikey_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.int] default_time_to_expire_token: Default expiration time of the Token within API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PlatformApiKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating ApiKeys.

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <parent_id>/<apikey_id>/<apikey_type>
        ```

        Import org level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <org_id>/<parent_id>/<apikey_id>/<apikey_type>
        ```

        Import project level apikey

        ```sh
        $ pulumi import harness:index/platformApiKey:PlatformApiKey harness_platform_apikey <org_id>/<project_id>/<parent_id>/<apikey_id>/<apikey_type>
        ```

        :param str resource_name: The name of the resource.
        :param PlatformApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PlatformApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
                 default_time_to_expire_token: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PlatformApiKeyArgs.__new__(PlatformApiKeyArgs)

            if account_id is None and not opts.urn:
                raise TypeError("Missing required property 'account_id'")
            __props__.__dict__["account_id"] = account_id
            if apikey_type is None and not opts.urn:
                raise TypeError("Missing required property 'apikey_type'")
            __props__.__dict__["apikey_type"] = apikey_type
            __props__.__dict__["default_time_to_expire_token"] = default_time_to_expire_token
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            if parent_id is None and not opts.urn:
                raise TypeError("Missing required property 'parent_id'")
            __props__.__dict__["parent_id"] = parent_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
        super(PlatformApiKey, __self__).__init__(
            'harness:index/platformApiKey:PlatformApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            apikey_type: Optional[pulumi.Input[_builtins.str]] = None,
            default_time_to_expire_token: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            parent_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'PlatformApiKey':
        """
        Get an existing PlatformApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account Identifier for the Entity
        :param pulumi.Input[_builtins.str] apikey_type: Type of the API Key
        :param pulumi.Input[_builtins.int] default_time_to_expire_token: Default expiration time of the Token within API Key
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] parent_id: Parent Entity Identifier of the API Key
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PlatformApiKeyState.__new__(_PlatformApiKeyState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["apikey_type"] = apikey_type
        __props__.__dict__["default_time_to_expire_token"] = default_time_to_expire_token
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["parent_id"] = parent_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        return PlatformApiKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account Identifier for the Entity
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="apikeyType")
    def apikey_type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the API Key
        """
        return pulumi.get(self, "apikey_type")

    @_builtins.property
    @pulumi.getter(name="defaultTimeToExpireToken")
    def default_time_to_expire_token(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Default expiration time of the Token within API Key
        """
        return pulumi.get(self, "default_time_to_expire_token")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="parentId")
    def parent_id(self) -> pulumi.Output[_builtins.str]:
        """
        Parent Entity Identifier of the API Key
        """
        return pulumi.get(self, "parent_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEnvironmentServiceOverridesResult',
    'AwaitableGetEnvironmentServiceOverridesResult',
    'get_environment_service_overrides',
    'get_environment_service_overrides_output',
]

@pulumi.output_type
class GetEnvironmentServiceOverridesResult:
    """
    A collection of values returned by getEnvironmentServiceOverrides.
    """
    def __init__(__self__, env_id=None, id=None, identifier=None, org_id=None, project_id=None, service_id=None, yaml=None):
        if env_id and not isinstance(env_id, str):
            raise TypeError("Expected argument 'env_id' to be a str")
        pulumi.set(__self__, "env_id", env_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if service_id and not isinstance(service_id, str):
            raise TypeError("Expected argument 'service_id' to be a str")
        pulumi.set(__self__, "service_id", service_id)
        if yaml and not isinstance(yaml, str):
            raise TypeError("Expected argument 'yaml' to be a str")
        pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter(name="envId")
    def env_id(self) -> _builtins.str:
        """
        The env ID to which the overrides associated.
        """
        return pulumi.get(self, "env_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        identifier of the service overrides.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="serviceId")
    def service_id(self) -> Optional[_builtins.str]:
        """
        The service ID to which the overrides applies.
        """
        return pulumi.get(self, "service_id")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> _builtins.str:
        """
        Environment Service Overrides YAML
        """
        return pulumi.get(self, "yaml")


class AwaitableGetEnvironmentServiceOverridesResult(GetEnvironmentServiceOverridesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnvironmentServiceOverridesResult(
            env_id=self.env_id,
            id=self.id,
            identifier=self.identifier,
            org_id=self.org_id,
            project_id=self.project_id,
            service_id=self.service_id,
            yaml=self.yaml)


def get_environment_service_overrides(env_id: Optional[_builtins.str] = None,
                                      identifier: Optional[_builtins.str] = None,
                                      org_id: Optional[_builtins.str] = None,
                                      project_id: Optional[_builtins.str] = None,
                                      service_id: Optional[_builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnvironmentServiceOverridesResult:
    """
    Data source for Harness environment service overrides.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_environment_service_overrides(org_id="orgIdentifier",
        project_id="projectIdentifier",
        env_id="environmentIdentifier",
        service_id="serviceIdentifier")
    ```


    :param _builtins.str env_id: The env ID to which the overrides associated.
    :param _builtins.str identifier: identifier of the service overrides.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str service_id: The service ID to which the overrides applies.
    """
    __args__ = dict()
    __args__['envId'] = env_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['serviceId'] = service_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getEnvironmentServiceOverrides:getEnvironmentServiceOverrides', __args__, opts=opts, typ=GetEnvironmentServiceOverridesResult).value

    return AwaitableGetEnvironmentServiceOverridesResult(
        env_id=pulumi.get(__ret__, 'env_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        service_id=pulumi.get(__ret__, 'service_id'),
        yaml=pulumi.get(__ret__, 'yaml'))
def get_environment_service_overrides_output(env_id: Optional[pulumi.Input[_builtins.str]] = None,
                                             identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             service_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEnvironmentServiceOverridesResult]:
    """
    Data source for Harness environment service overrides.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_environment_service_overrides(org_id="orgIdentifier",
        project_id="projectIdentifier",
        env_id="environmentIdentifier",
        service_id="serviceIdentifier")
    ```


    :param _builtins.str env_id: The env ID to which the overrides associated.
    :param _builtins.str identifier: identifier of the service overrides.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    :param _builtins.str service_id: The service ID to which the overrides applies.
    """
    __args__ = dict()
    __args__['envId'] = env_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['serviceId'] = service_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getEnvironmentServiceOverrides:getEnvironmentServiceOverrides', __args__, opts=opts, typ=GetEnvironmentServiceOverridesResult)
    return __ret__.apply(lambda __response__: GetEnvironmentServiceOverridesResult(
        env_id=pulumi.get(__response__, 'env_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        service_id=pulumi.get(__response__, 'service_id'),
        yaml=pulumi.get(__response__, 'yaml')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AzureKeyVaultConnectorArgs', 'AzureKeyVaultConnector']

@pulumi.input_type
class AzureKeyVaultConnectorArgs:
    def __init__(__self__, *,
                 client_id: pulumi.Input[_builtins.str],
                 identifier: pulumi.Input[_builtins.str],
                 secret_key: pulumi.Input[_builtins.str],
                 subscription: pulumi.Input[_builtins.str],
                 tenant_id: pulumi.Input[_builtins.str],
                 vault_name: pulumi.Input[_builtins.str],
                 azure_environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a AzureKeyVaultConnector resource.
        :param pulumi.Input[_builtins.str] client_id: Application ID of the Azure App.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] secret_key: The Harness text secret with the Azure authentication key as its value.
        :param pulumi.Input[_builtins.str] subscription: Azure subscription ID.
        :param pulumi.Input[_builtins.str] tenant_id: The Azure Active Directory (Azure AD) directory ID where you created your application.
        :param pulumi.Input[_builtins.str] vault_name: Name of the vault.
        :param pulumi.Input[_builtins.str] azure_environment_type: Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.bool] is_default: Specifies whether or not is the default value.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "client_id", client_id)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "secret_key", secret_key)
        pulumi.set(__self__, "subscription", subscription)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "vault_name", vault_name)
        if azure_environment_type is not None:
            pulumi.set(__self__, "azure_environment_type", azure_environment_type)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Input[_builtins.str]:
        """
        Application ID of the Azure App.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Input[_builtins.str]:
        """
        The Harness text secret with the Azure authentication key as its value.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def subscription(self) -> pulumi.Input[_builtins.str]:
        """
        Azure subscription ID.
        """
        return pulumi.get(self, "subscription")

    @subscription.setter
    def subscription(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subscription", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Azure Active Directory (Azure AD) directory ID where you created your application.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter(name="vaultName")
    def vault_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the vault.
        """
        return pulumi.get(self, "vault_name")

    @vault_name.setter
    def vault_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "vault_name", value)

    @_builtins.property
    @pulumi.getter(name="azureEnvironmentType")
    def azure_environment_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        """
        return pulumi.get(self, "azure_environment_type")

    @azure_environment_type.setter
    def azure_environment_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "azure_environment_type", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether or not is the default value.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _AzureKeyVaultConnectorState:
    def __init__(__self__, *,
                 azure_environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 subscription: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vault_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AzureKeyVaultConnector resources.
        :param pulumi.Input[_builtins.str] azure_environment_type: Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        :param pulumi.Input[_builtins.str] client_id: Application ID of the Azure App.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_default: Specifies whether or not is the default value.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_key: The Harness text secret with the Azure authentication key as its value.
        :param pulumi.Input[_builtins.str] subscription: Azure subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] tenant_id: The Azure Active Directory (Azure AD) directory ID where you created your application.
        :param pulumi.Input[_builtins.str] vault_name: Name of the vault.
        """
        if azure_environment_type is not None:
            pulumi.set(__self__, "azure_environment_type", azure_environment_type)
        if client_id is not None:
            pulumi.set(__self__, "client_id", client_id)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if subscription is not None:
            pulumi.set(__self__, "subscription", subscription)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if tenant_id is not None:
            pulumi.set(__self__, "tenant_id", tenant_id)
        if vault_name is not None:
            pulumi.set(__self__, "vault_name", vault_name)

    @_builtins.property
    @pulumi.getter(name="azureEnvironmentType")
    def azure_environment_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        """
        return pulumi.get(self, "azure_environment_type")

    @azure_environment_type.setter
    def azure_environment_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "azure_environment_type", value)

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application ID of the Azure App.
        """
        return pulumi.get(self, "client_id")

    @client_id.setter
    def client_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "client_id", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether or not is the default value.
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Harness text secret with the Azure authentication key as its value.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_key", value)

    @_builtins.property
    @pulumi.getter
    def subscription(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Azure subscription ID.
        """
        return pulumi.get(self, "subscription")

    @subscription.setter
    def subscription(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subscription", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Azure Active Directory (Azure AD) directory ID where you created your application.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tenant_id", value)

    @_builtins.property
    @pulumi.getter(name="vaultName")
    def vault_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the vault.
        """
        return pulumi.get(self, "vault_name")

    @vault_name.setter
    def vault_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vault_name", value)


@pulumi.type_token("harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector")
class AzureKeyVaultConnector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure_environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 subscription: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vault_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating an Azure key vault in Harness.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.AzureKeyVaultConnector("example",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            client_id="client_id",
            secret_key="account.secret_key",
            tenant_id="tenant_id",
            vault_name="vault_name",
            subscription="subscription",
            is_default=False,
            azure_environment_type="AZURE")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <connector_id>
        ```

        Import org level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <ord_id>/<connector_id>
        ```

        Import project level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] azure_environment_type: Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        :param pulumi.Input[_builtins.str] client_id: Application ID of the Azure App.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_default: Specifies whether or not is the default value.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_key: The Harness text secret with the Azure authentication key as its value.
        :param pulumi.Input[_builtins.str] subscription: Azure subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] tenant_id: The Azure Active Directory (Azure AD) directory ID where you created your application.
        :param pulumi.Input[_builtins.str] vault_name: Name of the vault.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AzureKeyVaultConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an Azure key vault in Harness.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.AzureKeyVaultConnector("example",
            identifier="identifier",
            name="name",
            description="example",
            tags=["foo:bar"],
            client_id="client_id",
            secret_key="account.secret_key",
            tenant_id="tenant_id",
            vault_name="vault_name",
            subscription="subscription",
            is_default=False,
            azure_environment_type="AZURE")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <connector_id>
        ```

        Import org level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <ord_id>/<connector_id>
        ```

        Import project level azure key vault connector

        ```sh
        $ pulumi import harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param AzureKeyVaultConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AzureKeyVaultConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 azure_environment_type: Optional[pulumi.Input[_builtins.str]] = None,
                 client_id: Optional[pulumi.Input[_builtins.str]] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_key: Optional[pulumi.Input[_builtins.str]] = None,
                 subscription: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
                 vault_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AzureKeyVaultConnectorArgs.__new__(AzureKeyVaultConnectorArgs)

            __props__.__dict__["azure_environment_type"] = azure_environment_type
            if client_id is None and not opts.urn:
                raise TypeError("Missing required property 'client_id'")
            __props__.__dict__["client_id"] = client_id
            __props__.__dict__["delegate_selectors"] = delegate_selectors
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if secret_key is None and not opts.urn:
                raise TypeError("Missing required property 'secret_key'")
            __props__.__dict__["secret_key"] = secret_key
            if subscription is None and not opts.urn:
                raise TypeError("Missing required property 'subscription'")
            __props__.__dict__["subscription"] = subscription
            __props__.__dict__["tags"] = tags
            if tenant_id is None and not opts.urn:
                raise TypeError("Missing required property 'tenant_id'")
            __props__.__dict__["tenant_id"] = tenant_id
            if vault_name is None and not opts.urn:
                raise TypeError("Missing required property 'vault_name'")
            __props__.__dict__["vault_name"] = vault_name
        super(AzureKeyVaultConnector, __self__).__init__(
            'harness:platform/azureKeyVaultConnector:AzureKeyVaultConnector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            azure_environment_type: Optional[pulumi.Input[_builtins.str]] = None,
            client_id: Optional[pulumi.Input[_builtins.str]] = None,
            delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_key: Optional[pulumi.Input[_builtins.str]] = None,
            subscription: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            tenant_id: Optional[pulumi.Input[_builtins.str]] = None,
            vault_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'AzureKeyVaultConnector':
        """
        Get an existing AzureKeyVaultConnector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] azure_environment_type: Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        :param pulumi.Input[_builtins.str] client_id: Application ID of the Azure App.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.bool] is_default: Specifies whether or not is the default value.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] secret_key: The Harness text secret with the Azure authentication key as its value.
        :param pulumi.Input[_builtins.str] subscription: Azure subscription ID.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] tenant_id: The Azure Active Directory (Azure AD) directory ID where you created your application.
        :param pulumi.Input[_builtins.str] vault_name: Name of the vault.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AzureKeyVaultConnectorState.__new__(_AzureKeyVaultConnectorState)

        __props__.__dict__["azure_environment_type"] = azure_environment_type
        __props__.__dict__["client_id"] = client_id
        __props__.__dict__["delegate_selectors"] = delegate_selectors
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["secret_key"] = secret_key
        __props__.__dict__["subscription"] = subscription
        __props__.__dict__["tags"] = tags
        __props__.__dict__["tenant_id"] = tenant_id
        __props__.__dict__["vault_name"] = vault_name
        return AzureKeyVaultConnector(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="azureEnvironmentType")
    def azure_environment_type(self) -> pulumi.Output[_builtins.str]:
        """
        Azure environment type. Possible values: AZURE or AZURE*US*GOVERNMENT. Default value: AZURE
        """
        return pulumi.get(self, "azure_environment_type")

    @_builtins.property
    @pulumi.getter(name="clientId")
    def client_id(self) -> pulumi.Output[_builtins.str]:
        """
        Application ID of the Azure App.
        """
        return pulumi.get(self, "client_id")

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Specifies whether or not is the default value.
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> pulumi.Output[_builtins.str]:
        """
        The Harness text secret with the Azure authentication key as its value.
        """
        return pulumi.get(self, "secret_key")

    @_builtins.property
    @pulumi.getter
    def subscription(self) -> pulumi.Output[_builtins.str]:
        """
        Azure subscription ID.
        """
        return pulumi.get(self, "subscription")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Azure Active Directory (Azure AD) directory ID where you created your application.
        """
        return pulumi.get(self, "tenant_id")

    @_builtins.property
    @pulumi.getter(name="vaultName")
    def vault_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the vault.
        """
        return pulumi.get(self, "vault_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InfraModuleArgs', 'InfraModule']

@pulumi.input_type
class InfraModuleArgs:
    def __init__(__self__, *,
                 system: pulumi.Input[_builtins.str],
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 synced: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[_builtins.str]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a InfraModule resource.
        :param pulumi.Input[_builtins.str] system: Provider of the module.
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created.
        :param pulumi.Input[_builtins.str] description: Description of the module.
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style.
        :param pulumi.Input[_builtins.str] name: Name of the module.
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module can be found
        :param pulumi.Input[_builtins.str] repository_branch: Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        :param pulumi.Input[_builtins.str] repository_commit: Tag to fetch the code from. This cannot be set if repository branch is set.
        :param pulumi.Input[_builtins.str] repository_connector: Reference to the connector to be used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Path to the module within the repository.
        :param pulumi.Input[_builtins.str] repository_url: URL of the repository where the module is stored.
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced.
        :param pulumi.Input[_builtins.str] tags: Git tags associated with the module.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: List of versions of the module.
        """
        pulumi.set(__self__, "system", system)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_tag_style is not None:
            pulumi.set(__self__, "git_tag_style", git_tag_style)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if repository_branch is not None:
            pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit is not None:
            pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector is not None:
            pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path is not None:
            pulumi.set(__self__, "repository_path", repository_path)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if synced is not None:
            pulumi.set(__self__, "synced", synced)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if versions is not None:
            pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter
    def system(self) -> pulumi.Input[_builtins.str]:
        """
        Provider of the module.
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "system", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the module.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git Tag Style.
        """
        return pulumi.get(self, "git_tag_style")

    @git_tag_style.setter
    def git_tag_style(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_tag_style", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the module.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For account connectors, the repository where the module can be found
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository", value)

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        """
        return pulumi.get(self, "repository_branch")

    @repository_branch.setter
    def repository_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_branch", value)

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tag to fetch the code from. This cannot be set if repository branch is set.
        """
        return pulumi.get(self, "repository_commit")

    @repository_commit.setter
    def repository_commit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_commit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reference to the connector to be used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @repository_connector.setter
    def repository_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the module within the repository.
        """
        return pulumi.get(self, "repository_path")

    @repository_path.setter
    def repository_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_path", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the repository where the module is stored.
        """
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_url", value)

    @_builtins.property
    @pulumi.getter
    def synced(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was last synced.
        """
        return pulumi.get(self, "synced")

    @synced.setter
    def synced(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "synced", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git tags associated with the module.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of versions of the module.
        """
        return pulumi.get(self, "versions")

    @versions.setter
    def versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "versions", value)


@pulumi.input_type
class _InfraModuleState:
    def __init__(__self__, *,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 synced: Optional[pulumi.Input[_builtins.int]] = None,
                 system: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[_builtins.str]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering InfraModule resources.
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created.
        :param pulumi.Input[_builtins.str] description: Description of the module.
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style.
        :param pulumi.Input[_builtins.str] name: Name of the module.
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module can be found
        :param pulumi.Input[_builtins.str] repository_branch: Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        :param pulumi.Input[_builtins.str] repository_commit: Tag to fetch the code from. This cannot be set if repository branch is set.
        :param pulumi.Input[_builtins.str] repository_connector: Reference to the connector to be used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Path to the module within the repository.
        :param pulumi.Input[_builtins.str] repository_url: URL of the repository where the module is stored.
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced.
        :param pulumi.Input[_builtins.str] system: Provider of the module.
        :param pulumi.Input[_builtins.str] tags: Git tags associated with the module.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: List of versions of the module.
        """
        if created is not None:
            pulumi.set(__self__, "created", created)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_tag_style is not None:
            pulumi.set(__self__, "git_tag_style", git_tag_style)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if repository_branch is not None:
            pulumi.set(__self__, "repository_branch", repository_branch)
        if repository_commit is not None:
            pulumi.set(__self__, "repository_commit", repository_commit)
        if repository_connector is not None:
            pulumi.set(__self__, "repository_connector", repository_connector)
        if repository_path is not None:
            pulumi.set(__self__, "repository_path", repository_path)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if synced is not None:
            pulumi.set(__self__, "synced", synced)
        if system is not None:
            pulumi.set(__self__, "system", system)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if versions is not None:
            pulumi.set(__self__, "versions", versions)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the module.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git Tag Style.
        """
        return pulumi.get(self, "git_tag_style")

    @git_tag_style.setter
    def git_tag_style(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_tag_style", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the module.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        For account connectors, the repository where the module can be found
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository", value)

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        """
        return pulumi.get(self, "repository_branch")

    @repository_branch.setter
    def repository_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_branch", value)

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Tag to fetch the code from. This cannot be set if repository branch is set.
        """
        return pulumi.get(self, "repository_commit")

    @repository_commit.setter
    def repository_commit(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_commit", value)

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reference to the connector to be used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @repository_connector.setter
    def repository_connector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_connector", value)

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Path to the module within the repository.
        """
        return pulumi.get(self, "repository_path")

    @repository_path.setter
    def repository_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_path", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the repository where the module is stored.
        """
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_url", value)

    @_builtins.property
    @pulumi.getter
    def synced(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the module was last synced.
        """
        return pulumi.get(self, "synced")

    @synced.setter
    def synced(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "synced", value)

    @_builtins.property
    @pulumi.getter
    def system(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provider of the module.
        """
        return pulumi.get(self, "system")

    @system.setter
    def system(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "system", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git tags associated with the module.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def versions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of versions of the module.
        """
        return pulumi.get(self, "versions")

    @versions.setter
    def versions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "versions", value)


@pulumi.type_token("harness:platform/infraModule:InfraModule")
class InfraModule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 synced: Optional[pulumi.Input[_builtins.int]] = None,
                 system: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[_builtins.str]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraModule("example",
            description="example",
            name="name",
            system="provider",
            repository="https://github.com/org/repo",
            repository_branch="main",
            repository_path="tf/aws/basic",
            repository_connector=test["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/infraModule:InfraModule example <module_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created.
        :param pulumi.Input[_builtins.str] description: Description of the module.
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style.
        :param pulumi.Input[_builtins.str] name: Name of the module.
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module can be found
        :param pulumi.Input[_builtins.str] repository_branch: Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        :param pulumi.Input[_builtins.str] repository_commit: Tag to fetch the code from. This cannot be set if repository branch is set.
        :param pulumi.Input[_builtins.str] repository_connector: Reference to the connector to be used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Path to the module within the repository.
        :param pulumi.Input[_builtins.str] repository_url: URL of the repository where the module is stored.
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced.
        :param pulumi.Input[_builtins.str] system: Provider of the module.
        :param pulumi.Input[_builtins.str] tags: Git tags associated with the module.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: List of versions of the module.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InfraModuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraModule("example",
            description="example",
            name="name",
            system="provider",
            repository="https://github.com/org/repo",
            repository_branch="main",
            repository_path="tf/aws/basic",
            repository_connector=test["id"])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        ```sh
        $ pulumi import harness:platform/infraModule:InfraModule example <module_id>
        ```

        :param str resource_name: The name of the resource.
        :param InfraModuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InfraModuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 repository: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_path: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 synced: Optional[pulumi.Input[_builtins.int]] = None,
                 system: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[_builtins.str]] = None,
                 versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InfraModuleArgs.__new__(InfraModuleArgs)

            __props__.__dict__["created"] = created
            __props__.__dict__["description"] = description
            __props__.__dict__["git_tag_style"] = git_tag_style
            __props__.__dict__["name"] = name
            __props__.__dict__["repository"] = repository
            __props__.__dict__["repository_branch"] = repository_branch
            __props__.__dict__["repository_commit"] = repository_commit
            __props__.__dict__["repository_connector"] = repository_connector
            __props__.__dict__["repository_path"] = repository_path
            __props__.__dict__["repository_url"] = repository_url
            __props__.__dict__["synced"] = synced
            if system is None and not opts.urn:
                raise TypeError("Missing required property 'system'")
            __props__.__dict__["system"] = system
            __props__.__dict__["tags"] = tags
            __props__.__dict__["versions"] = versions
        super(InfraModule, __self__).__init__(
            'harness:platform/infraModule:InfraModule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_tag_style: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            repository: Optional[pulumi.Input[_builtins.str]] = None,
            repository_branch: Optional[pulumi.Input[_builtins.str]] = None,
            repository_commit: Optional[pulumi.Input[_builtins.str]] = None,
            repository_connector: Optional[pulumi.Input[_builtins.str]] = None,
            repository_path: Optional[pulumi.Input[_builtins.str]] = None,
            repository_url: Optional[pulumi.Input[_builtins.str]] = None,
            synced: Optional[pulumi.Input[_builtins.int]] = None,
            system: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[_builtins.str]] = None,
            versions: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'InfraModule':
        """
        Get an existing InfraModule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] created: Timestamp when the module was created.
        :param pulumi.Input[_builtins.str] description: Description of the module.
        :param pulumi.Input[_builtins.str] git_tag_style: Git Tag Style.
        :param pulumi.Input[_builtins.str] name: Name of the module.
        :param pulumi.Input[_builtins.str] repository: For account connectors, the repository where the module can be found
        :param pulumi.Input[_builtins.str] repository_branch: Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        :param pulumi.Input[_builtins.str] repository_commit: Tag to fetch the code from. This cannot be set if repository branch is set.
        :param pulumi.Input[_builtins.str] repository_connector: Reference to the connector to be used to fetch the code.
        :param pulumi.Input[_builtins.str] repository_path: Path to the module within the repository.
        :param pulumi.Input[_builtins.str] repository_url: URL of the repository where the module is stored.
        :param pulumi.Input[_builtins.int] synced: Timestamp when the module was last synced.
        :param pulumi.Input[_builtins.str] system: Provider of the module.
        :param pulumi.Input[_builtins.str] tags: Git tags associated with the module.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] versions: List of versions of the module.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InfraModuleState.__new__(_InfraModuleState)

        __props__.__dict__["created"] = created
        __props__.__dict__["description"] = description
        __props__.__dict__["git_tag_style"] = git_tag_style
        __props__.__dict__["name"] = name
        __props__.__dict__["repository"] = repository
        __props__.__dict__["repository_branch"] = repository_branch
        __props__.__dict__["repository_commit"] = repository_commit
        __props__.__dict__["repository_connector"] = repository_connector
        __props__.__dict__["repository_path"] = repository_path
        __props__.__dict__["repository_url"] = repository_url
        __props__.__dict__["synced"] = synced
        __props__.__dict__["system"] = system
        __props__.__dict__["tags"] = tags
        __props__.__dict__["versions"] = versions
        return InfraModule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the module was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the module.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitTagStyle")
    def git_tag_style(self) -> pulumi.Output[_builtins.str]:
        """
        Git Tag Style.
        """
        return pulumi.get(self, "git_tag_style")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the module.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def repository(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        For account connectors, the repository where the module can be found
        """
        return pulumi.get(self, "repository")

    @_builtins.property
    @pulumi.getter(name="repositoryBranch")
    def repository_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the branch to fetch the code from. This cannot be set if repository commit is set.
        """
        return pulumi.get(self, "repository_branch")

    @_builtins.property
    @pulumi.getter(name="repositoryCommit")
    def repository_commit(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Tag to fetch the code from. This cannot be set if repository branch is set.
        """
        return pulumi.get(self, "repository_commit")

    @_builtins.property
    @pulumi.getter(name="repositoryConnector")
    def repository_connector(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Reference to the connector to be used to fetch the code.
        """
        return pulumi.get(self, "repository_connector")

    @_builtins.property
    @pulumi.getter(name="repositoryPath")
    def repository_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Path to the module within the repository.
        """
        return pulumi.get(self, "repository_path")

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the repository where the module is stored.
        """
        return pulumi.get(self, "repository_url")

    @_builtins.property
    @pulumi.getter
    def synced(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the module was last synced.
        """
        return pulumi.get(self, "synced")

    @_builtins.property
    @pulumi.getter
    def system(self) -> pulumi.Output[_builtins.str]:
        """
        Provider of the module.
        """
        return pulumi.get(self, "system")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[_builtins.str]:
        """
        Git tags associated with the module.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def versions(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of versions of the module.
        """
        return pulumi.get(self, "versions")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetEncryptedTextResult',
    'AwaitableGetEncryptedTextResult',
    'get_encrypted_text',
    'get_encrypted_text_output',
]

@pulumi.output_type
class GetEncryptedTextResult:
    """
    A collection of values returned by getEncryptedText.
    """
    def __init__(__self__, id=None, name=None, secret_manager_id=None, usage_scopes=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if secret_manager_id and not isinstance(secret_manager_id, str):
            raise TypeError("Expected argument 'secret_manager_id' to be a str")
        pulumi.set(__self__, "secret_manager_id", secret_manager_id)
        if usage_scopes and not isinstance(usage_scopes, list):
            raise TypeError("Expected argument 'usage_scopes' to be a list")
        pulumi.set(__self__, "usage_scopes", usage_scopes)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the encrypted secret
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the encrypted secret
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="secretManagerId")
    def secret_manager_id(self) -> _builtins.str:
        """
        The id of the associated secret manager
        """
        return pulumi.get(self, "secret_manager_id")

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> Optional[Sequence['outputs.GetEncryptedTextUsageScopeResult']]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")


class AwaitableGetEncryptedTextResult(GetEncryptedTextResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEncryptedTextResult(
            id=self.id,
            name=self.name,
            secret_manager_id=self.secret_manager_id,
            usage_scopes=self.usage_scopes)


def get_encrypted_text(id: Optional[_builtins.str] = None,
                       name: Optional[_builtins.str] = None,
                       usage_scopes: Optional[Sequence[Union['GetEncryptedTextUsageScopeArgs', 'GetEncryptedTextUsageScopeArgsDict']]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEncryptedTextResult:
    """
    Data source for retrieving a Harness application


    :param _builtins.str id: Unique identifier of the encrypted secret
    :param _builtins.str name: The name of the encrypted secret
    :param Sequence[Union['GetEncryptedTextUsageScopeArgs', 'GetEncryptedTextUsageScopeArgsDict']] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['usageScopes'] = usage_scopes
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getEncryptedText:getEncryptedText', __args__, opts=opts, typ=GetEncryptedTextResult).value

    return AwaitableGetEncryptedTextResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        secret_manager_id=pulumi.get(__ret__, 'secret_manager_id'),
        usage_scopes=pulumi.get(__ret__, 'usage_scopes'))
def get_encrypted_text_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                              usage_scopes: Optional[pulumi.Input[Optional[Sequence[Union['GetEncryptedTextUsageScopeArgs', 'GetEncryptedTextUsageScopeArgsDict']]]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEncryptedTextResult]:
    """
    Data source for retrieving a Harness application


    :param _builtins.str id: Unique identifier of the encrypted secret
    :param _builtins.str name: The name of the encrypted secret
    :param Sequence[Union['GetEncryptedTextUsageScopeArgs', 'GetEncryptedTextUsageScopeArgsDict']] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['name'] = name
    __args__['usageScopes'] = usage_scopes
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getEncryptedText:getEncryptedText', __args__, opts=opts, typ=GetEncryptedTextResult)
    return __ret__.apply(lambda __response__: GetEncryptedTextResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        secret_manager_id=pulumi.get(__response__, 'secret_manager_id'),
        usage_scopes=pulumi.get(__response__, 'usage_scopes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGitopsAgentResult',
    'AwaitableGetGitopsAgentResult',
    'get_gitops_agent',
    'get_gitops_agent_output',
]

@pulumi.output_type
class GetGitopsAgentResult:
    """
    A collection of values returned by getGitopsAgent.
    """
    def __init__(__self__, account_id=None, agent_token=None, description=None, id=None, identifier=None, is_authenticated=None, metadatas=None, name=None, operator=None, org_id=None, prefixed_identifier=None, project_id=None, tags=None, type=None, with_credentials=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_token and not isinstance(agent_token, str):
            raise TypeError("Expected argument 'agent_token' to be a str")
        pulumi.set(__self__, "agent_token", agent_token)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if is_authenticated and not isinstance(is_authenticated, bool):
            raise TypeError("Expected argument 'is_authenticated' to be a bool")
        pulumi.set(__self__, "is_authenticated", is_authenticated)
        if metadatas and not isinstance(metadatas, list):
            raise TypeError("Expected argument 'metadatas' to be a list")
        pulumi.set(__self__, "metadatas", metadatas)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if operator and not isinstance(operator, str):
            raise TypeError("Expected argument 'operator' to be a str")
        pulumi.set(__self__, "operator", operator)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if prefixed_identifier and not isinstance(prefixed_identifier, str):
            raise TypeError("Expected argument 'prefixed_identifier' to be a str")
        pulumi.set(__self__, "prefixed_identifier", prefixed_identifier)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if with_credentials and not isinstance(with_credentials, bool):
            raise TypeError("Expected argument 'with_credentials' to be a bool")
        pulumi.set(__self__, "with_credentials", with_credentials)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps agent.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentToken")
    def agent_token(self) -> _builtins.str:
        """
        Agent token to be used for authentication of the agent with Harness.
        """
        return pulumi.get(self, "agent_token")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the GitOps agent.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Identifier of the GitOps agent.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="isAuthenticated")
    def is_authenticated(self) -> _builtins.bool:
        """
        This computed field specifies if the referenced agent ever successfully connected and was authenticated to harness. Note that this is different from whether the agent is currently connected. \\n\\nSet with_credentials to true to allow computing of this field.\\n\\n For retrieval of this information, the user associated to the token being used must have Gitops Agent Edit permissions
        """
        return pulumi.get(self, "is_authenticated")

    @_builtins.property
    @pulumi.getter
    def metadatas(self) -> Sequence['outputs.GetGitopsAgentMetadataResult']:
        """
        Metadata of the agent.
        """
        return pulumi.get(self, "metadatas")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the GitOps agent.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def operator(self) -> _builtins.str:
        """
        The Operator to use for the Harness GitOps agent. Enum: "ARGO" "FLAMINGO"
        """
        return pulumi.get(self, "operator")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Organization identifier of the GitOps agent.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="prefixedIdentifier")
    def prefixed_identifier(self) -> _builtins.str:
        """
        Prefixed identifier of the GitOps agent. Agent identifier prefixed with scope of the agent
        """
        return pulumi.get(self, "prefixed_identifier")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the GitOps agent.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        Tags for the GitOps agents. These can be used to search or filter the GitOps agents.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Default: "AGENT*TYPE*UNSET"
        Enum: "AGENT*TYPE*UNSET" "CONNECTED*ARGO*PROVIDER" "MANAGED*ARGO*PROVIDER"
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="withCredentials")
    def with_credentials(self) -> Optional[_builtins.bool]:
        """
        Specify whether to retrieve the gitops agent's token. (The field agent_token will be populated only if the agent has never connected to Harness before). For retrieval of this information, the user associated to the token being used must have Gitops Agent Edit permissions
        """
        return pulumi.get(self, "with_credentials")


class AwaitableGetGitopsAgentResult(GetGitopsAgentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAgentResult(
            account_id=self.account_id,
            agent_token=self.agent_token,
            description=self.description,
            id=self.id,
            identifier=self.identifier,
            is_authenticated=self.is_authenticated,
            metadatas=self.metadatas,
            name=self.name,
            operator=self.operator,
            org_id=self.org_id,
            prefixed_identifier=self.prefixed_identifier,
            project_id=self.project_id,
            tags=self.tags,
            type=self.type,
            with_credentials=self.with_credentials)


def get_gitops_agent(account_id: Optional[_builtins.str] = None,
                     identifier: Optional[_builtins.str] = None,
                     org_id: Optional[_builtins.str] = None,
                     project_id: Optional[_builtins.str] = None,
                     with_credentials: Optional[_builtins.bool] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAgentResult:
    """
    Datasource for fetching a Harness GitOps Agent.


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param _builtins.bool with_credentials: Specify whether to retrieve the gitops agent's token. (The field agent_token will be populated only if the agent has never connected to Harness before). For retrieval of this information, the user associated to the token being used must have Gitops Agent Edit permissions
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['withCredentials'] = with_credentials
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAgent:getGitopsAgent', __args__, opts=opts, typ=GetGitopsAgentResult).value

    return AwaitableGetGitopsAgentResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_token=pulumi.get(__ret__, 'agent_token'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        is_authenticated=pulumi.get(__ret__, 'is_authenticated'),
        metadatas=pulumi.get(__ret__, 'metadatas'),
        name=pulumi.get(__ret__, 'name'),
        operator=pulumi.get(__ret__, 'operator'),
        org_id=pulumi.get(__ret__, 'org_id'),
        prefixed_identifier=pulumi.get(__ret__, 'prefixed_identifier'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        with_credentials=pulumi.get(__ret__, 'with_credentials'))
def get_gitops_agent_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            identifier: Optional[pulumi.Input[_builtins.str]] = None,
                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                            with_credentials: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAgentResult]:
    """
    Datasource for fetching a Harness GitOps Agent.


    :param _builtins.str account_id: Account identifier of the GitOps agent.
    :param _builtins.str identifier: Identifier of the GitOps agent.
    :param _builtins.str org_id: Organization identifier of the GitOps agent.
    :param _builtins.str project_id: Project identifier of the GitOps agent.
    :param _builtins.bool with_credentials: Specify whether to retrieve the gitops agent's token. (The field agent_token will be populated only if the agent has never connected to Harness before). For retrieval of this information, the user associated to the token being used must have Gitops Agent Edit permissions
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['identifier'] = identifier
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['withCredentials'] = with_credentials
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAgent:getGitopsAgent', __args__, opts=opts, typ=GetGitopsAgentResult)
    return __ret__.apply(lambda __response__: GetGitopsAgentResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_token=pulumi.get(__response__, 'agent_token'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        is_authenticated=pulumi.get(__response__, 'is_authenticated'),
        metadatas=pulumi.get(__response__, 'metadatas'),
        name=pulumi.get(__response__, 'name'),
        operator=pulumi.get(__response__, 'operator'),
        org_id=pulumi.get(__response__, 'org_id'),
        prefixed_identifier=pulumi.get(__response__, 'prefixed_identifier'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        with_credentials=pulumi.get(__response__, 'with_credentials')))
